# -*- coding: utf-8 -*-

# Copyright © 2018 by IBPort. All rights reserved.
# @Author: Neal Wong
# @Email: ibprnd@gmail.com

from cmutils.misc import to_unicode, to_bytes, to_native_str

import pytest


def test_to_unicode():
    # Converting an utf8 encoded string to unicode
    assert to_unicode(b'lel\xc3\xb1e') == u'lel\xf1e'

    # Converting a latin_1 encoded string to unicode
    assert to_unicode(b'lel\xf1e', 'latin-1') == u'lel\xf1e'

    # Converting a unicode to unicode should return the same object
    assert to_unicode(u'\xf1e\xf1e\xf1e') == u'\xf1e\xf1e\xf1e'

    # Converting a strange object should raise TypeError
    with pytest.raises(TypeError):
        to_unicode(423)

    # Errors argument
    assert to_unicode(b'a\xedb', 'utf-8', errors='replace') == u'a\ufffdb'

def test_to_bytes():
    # Converting a unicode object to an utf-8 encoded string
    assert to_bytes(u'\xa3 49') == b'\xc2\xa3 49'

    # Converting a unicode object to a latin-1 encoded string
    assert to_bytes(u'\xa3 49', 'latin-1') == b'\xa3 49'

    # Converting a regular bytes to bytes should return the same object
    assert to_bytes(b'lel\xf1e') == b'lel\xf1e'

    # Converting a strange object should raise TypeError
    with pytest.raises(TypeError):
         to_bytes(423)

    # Errors argument
    assert to_bytes(u'a\ufffdb', 'latin-1', errors='replace') == b'a?b'
